@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 BEGIN { $| = 1; }
 use warnings;
 use strict;
@@ -8,7 +8,7 @@ use Digest::SHA qw(sha1_hex);
 Getopt::Long::Configure('no_ignore_case');
 
 # This is updated by the update-revision.pl script.
-my $revision = 12312;
+my $revision = 13891;
 
 # Generate list with:
 # vislcg3 --help 2>&1 | perl -wpne 'if (/^ / && /-(\w), --([-\w]+)/) {print "$2|$1=s\n"} elsif (/^ / && /--([-\w]+)/) {print "$1=s\n"} s/^.*$//s;' | perl -wpne 's/^/"/; s/$/",/;'
@@ -47,6 +47,7 @@ GetOptions (\%h,
 "trace-name-only",
 "trace-no-removed",
 "trace-encl",
+"deleted",
 "dry-run",
 "single-run",
 "max-runs=s",
@@ -60,6 +61,7 @@ GetOptions (\%h,
 "always-span",
 "soft-limit=s",
 "hard-limit=s",
+"text-delimit|T:s",
 "dep-delimit|D:s",
 "dep-original",
 "dep-allow-loops",
@@ -72,7 +74,8 @@ GetOptions (\%h,
 "show-tags",
 "show-tag-hashes",
 "show-set-hashes",
-"dump-ast"
+"dump-ast",
+"no-break|B",
 );
 
 if (defined $h{'grammar-bin'}) {
@@ -118,7 +121,7 @@ if (!(-r $bn) && !(-r $bn.".lock")) {
 
 my $cmd = '';
 if (-r $bn && !(-r $bn.".lock")) {
-	print STDERR "CG3 AutoBin using $bn\n";
+#	print STDERR "CG3 AutoBin using $bn\n";
 	$cmd = "cat /dev/stdin | $bin $args --grammar $bn";
 }
 else {
